@@ -7,13 +7,17 @@
 import math
 import volmdlr
 from volmdlr.primitives import RoundedLineSegments
+import matplotlib.pyplot as plt
 
-
-class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
-    def __init__(self, points, radius, closed=False, adapt_radius=False, name=''):
+        
+class OpenedRoundedLineSegments2D(RoundedLineSegments, volmdlr.Wire2D):
+    closed= False
+    def __init__(self, points, radius, adapt_radius=False, name=''):
         primitives = RoundedLineSegments.__init__(self, points, radius,
                                                   volmdlr.LineSegment2D, volmdlr.Arc2D,
-                                                  closed, adapt_radius, name='')
+                                                  closed=False,
+                                                  adapt_radius=adapt_radius,
+                                                  name='')
 
         volmdlr.Wire2D.__init__(self, primitives, name)
 
@@ -35,7 +39,7 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
             pti = self.points[ipoint]
             pt2 = self.points[ipoint + 1]
 
-        # TODO: change to PointDistance
+        # TODO: change to point_distance
         dist1 = (pt1-pti).Norm()
         dist2 = (pt2-pti).Norm()
         dist3 = (pt1-pt2).Norm()
@@ -52,7 +56,7 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
         if w != volmdlr.Vector2D((0, 0)):
             w.Normalize()
 
-        v1 = u1.NormalVector()
+        v1 = u1.deterministic_unit_normal_vector()
         if v1.Dot(w) < 0:
             v1 = -v1
 
@@ -64,23 +68,23 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
 
     def Rotation(self, center, angle, copy=True):
         if copy:
-            return RoundedLineSegments2D([p.Rotation(center, angle, copy=True)\
+            return self.__class__([p.Rotation(center, angle, copy=True)\
                                           for p in self.points],
-                                          self.radius, self.closed,
+                                          self.radius,
                                           adapt_radius =self.adapt_radius,
                                           name = self.name)
         else:
             self.__init__([p.Rotation(center, angle, copy=True) for p in self.points],
-                           self.radius, self.closed,
+                           self.radius,
                            adapt_radius=self.adapt_radius, name = self.name)
 
     def Translation(self, offset, copy=True):
         if copy:
-            return RoundedLineSegments2D([p.Translation(offset, copy=True) for p in self.points],
-                                          self.radius, self.closed, adapt_radius=self.adapt_radius, name = self.name)
+            return self.__class__([p.Translation(offset, copy=True) for p in self.points],
+                                  self.radius, adapt_radius=self.adapt_radius, name = self.name)
         else:
             self.__init__([p.Translation(offset,copy=True) for p in self.points],
-                           self.radius, self.closed, adapt_radius =self.adapt_radius, name = self.name)
+                          self.radius, adapt_radius =self.adapt_radius, name = self.name)
 
     def Offset(self, offset):
         nb = len(self.points)
@@ -152,9 +156,7 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
             offset_vectors.append(n_last)
             offset_points.append(self.points[-1] + offset*offset_vectors[-1])
 
-        return RoundedLineSegments2D(offset_points, new_radii, self.closed,
-                                         adapt_radius=self.adapt_radius)
-        
+        return self.__class__(offset_points, new_radii, adapt_radius=self.adapt_radius)
         
     def OffsetSingleLine(self, line_index, offset):
         """
@@ -238,7 +240,7 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
         if not dont_add_last_point and not self.closed:
             new_linesegment2D_points.append(self.points[-1])
         
-        rls2D = RoundedLineSegments2D(new_linesegment2D_points, self.radius,
+        rls2D = self.__class__(new_linesegment2D_points, self.radius,
                                                  self.closed, adapt_radius=self.adapt_radius)
         
         return rls2D
@@ -287,7 +289,7 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
     
 # =============================================================================
 # COMPUTES THE ANGLE BETWEEN THE NORMAL VECTOR OF THE SURFACE TO OFFSET AND 
-# THE DIRETIVE VECTOR IN ORDER TO SET THE NEW POINT AT THE RIGHT DISTANCE
+# THE DIRECTIVE VECTOR IN ORDER TO SET THE NEW POINT AT THE RIGHT DISTANCE
 # =============================================================================
         normal_vectors = []
         for index in line_indexes:
@@ -313,8 +315,8 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
         
         if len(line_indexes) > 1:
             intersection = volmdlr.Point2D.LinesIntersection(volmdlr.Line2D(self.points[line_indexes[0]], self.points[line_indexes[0]]+dir_vec_1), volmdlr.Line2D(self.points[line_indexes[-1]+1], self.points[line_indexes[-1]+1]+dir_vec_2))
-            vec1 = intersection.PointDistance(self.points[line_indexes[0]]) * dir_vec_1
-            vec2 = intersection.PointDistance(self.points[line_indexes[-1]+1]) * dir_vec_2
+            vec1 = intersection.point_distance(self.points[line_indexes[0]]) * dir_vec_1
+            vec2 = intersection.point_distance(self.points[line_indexes[-1]+1]) * dir_vec_2
         
 # =============================================================================
 # COMPUTES THE NEW POINTS AFTER THE OFFSET
@@ -324,7 +326,7 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
         new_points[line_indexes[0]] = self.points[line_indexes[0]] + distance_dir1 * dir_vec_1
         
         for nb, index in enumerate(line_indexes[1:]):
-            coeff_vec_2 = volmdlr.Point2D.PointDistance(self.points[line_indexes[0]], self.points[index]) / volmdlr.Point2D.PointDistance(self.points[line_indexes[0]], self.points[line_indexes[-1]+1])
+            coeff_vec_2 = volmdlr.Point2D.point_distance(self.points[line_indexes[0]], self.points[index]) / volmdlr.Point2D.point_distance(self.points[line_indexes[0]], self.points[line_indexes[-1]+1])
             coeff_vec_1 = 1 - coeff_vec_2
             if dir_vec_1.Dot(normal_vectors[nb+1]) < 0:
                 coeff_vec_1 = - coeff_vec_1
@@ -350,8 +352,24 @@ class RoundedLineSegments2D(volmdlr.Wire2D, RoundedLineSegments):
                 new_linesegment2D_points.append(self.points[i])
                 
         
-        rls2D = RoundedLineSegments2D(new_linesegment2D_points, self.radius,
-                                                 self.closed, adapt_radius=self.adapt_radius)
+        rls2D = self.__class__(new_linesegment2D_points, self.radius,
+                                                 adapt_radius=self.adapt_radius)
         
 
-        return rls2D
\ No newline at end of file
+        return rls2D
+    
+class ClosedRoundedLineSegments2D(OpenedRoundedLineSegments2D, volmdlr.Contour2D):
+    """
+    :param points: Points used to draw the wire 
+    :type points: List of Point2D
+    :param radius: Radius used to connect different parts of the wire
+    :type radius: {position1(n): float which is the radius linked the n-1 and n+1 points, position2(n+1):...}
+    """
+    closed = True
+    def __init__(self, points, radius, adapt_radius=False, name=''):
+        primitives = RoundedLineSegments.__init__(self, points, radius,
+                                                  volmdlr.LineSegment2D, volmdlr.Arc2D,
+                                                  closed=True,
+                                                  adapt_radius=adapt_radius, name='')
+
+        volmdlr.Contour2D.__init__(self, primitives, name)
\ No newline at end of file
